HeaderFileGenerator

Struct HeaderFileGenerator 

pub struct HeaderFileGenerator { /* private fields */ }
Generator of head file, use it to generate a header file and then include it in user codes.

Use only if you just want to generate a header file, and do the linking job yourself, or you should use Builder instead.

Examples:

use optee_utee_build::{HeaderFileGenerator, TaConfig, RustEdition};
const UUID: &str = "26509cec-4a2b-4935-87ab-762d89fbf0b0";
let ta_config = TaConfig::new_default(UUID, "0.1.0", "example")?;
let codes = HeaderFileGenerator::new(RustEdition::Before2024).generate(&ta_config)?;

Implementations

Source

impl HeaderFileGenerator

pub fn new(edition: RustEdition) -> Self

pub fn generate(self, conf: &TaConfig) -> Result<String, Error>