Skip to main content Crate optee_utee_build Copy item path Source Builder The Builder of TA, use it to handle file generation and linking stuff HeaderFileGenerator Generator of head file, use it to generate a header file and then include it in user codes. Linker Linker of ta, use it to handle all linking stuff. Property A GP property pair, use it to set ta_properties TaConfig Configuration options for TA Uuid A Universally Unique Identifier (UUID). Error LinkerType The type of the linker, there are difference when using gcc/cc or ld/lld as
linker, For example, --sort-section=alignment parameter changes to
-Wl,--sort-section=alignment when using gcc as linker. PropertyValue An enum of PropertyValue, with its type and value combined RustEdition Start from rust edition 2024, no_mangle and link_section must be wrapped with unsafe build a build method, use it for TA compilation
Usage: